==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney.md <==
# AmazonPinpointJourney


```text
aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney
```

```text
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')
```



| Illustration | AmazonPinpointJourney | AmazonPinpointJourneyCard | AmazonPinpointJourneyGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney.png) | ![illustration for AmazonPinpointJourney](../../../aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney.Local.png) | ![illustration for AmazonPinpointJourneyCard](../../../aws-20210730/Resource/BusinessApplications/AmazonPinpointJourneyCard.Local.png) | ![illustration for AmazonPinpointJourneyGroup](../../../aws-20210730/Resource/BusinessApplications/AmazonPinpointJourneyGroup.Local.png) |




## AmazonPinpointJourney

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonPinpointJourney
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')

' renders the element
AmazonPinpointJourney('AmazonPinpointJourney', 'Amazon Pinpoint Journey', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonPinpointJourney
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')

' renders the element
AmazonPinpointJourney('AmazonPinpointJourney', 'Amazon Pinpoint Journey', 'an optional tech label')
@enduml
```

## AmazonPinpointJourneyCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonPinpointJourneyCard
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')

' renders the element
AmazonPinpointJourneyCard('AmazonPinpointJourneyCard', 'Amazon Pinpoint Journey Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonPinpointJourneyCard
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')

' renders the element
AmazonPinpointJourneyCard('AmazonPinpointJourneyCard', 'Amazon Pinpoint Journey Card', 'an optional description')
@enduml
```

## AmazonPinpointJourneyGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonPinpointJourneyGroup
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')

' renders the element
AmazonPinpointJourneyGroup('AmazonPinpointJourneyGroup', 'Amazon Pinpoint Journey Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonPinpointJourneyGroup
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')

' renders the element
AmazonPinpointJourneyGroup('AmazonPinpointJourneyGroup', 'Amazon Pinpoint Journey Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney.md <==
# AmazonPinpointJourney


```text
aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney
```

```text
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')
```



| Illustration | AmazonPinpointJourney | AmazonPinpointJourneyCard | AmazonPinpointJourneyGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney.png) | ![illustration for AmazonPinpointJourney](../../../aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney.Local.png) | ![illustration for AmazonPinpointJourneyCard](../../../aws-20210730/Resource/BusinessApplications/AmazonPinpointJourneyCard.Local.png) | ![illustration for AmazonPinpointJourneyGroup](../../../aws-20210730/Resource/BusinessApplications/AmazonPinpointJourneyGroup.Local.png) |




## AmazonPinpointJourney

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonPinpointJourney
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')

' renders the element
AmazonPinpointJourney('AmazonPinpointJourney', 'Amazon Pinpoint Journey', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonPinpointJourney
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')

' renders the element
AmazonPinpointJourney('AmazonPinpointJourney', 'Amazon Pinpoint Journey', 'an optional tech label')
@enduml
```

## AmazonPinpointJourneyCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonPinpointJourneyCard
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')

' renders the element
AmazonPinpointJourneyCard('AmazonPinpointJourneyCard', 'Amazon Pinpoint Journey Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonPinpointJourneyCard
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')

' renders the element
AmazonPinpointJourneyCard('AmazonPinpointJourneyCard', 'Amazon Pinpoint Journey Card', 'an optional description')
@enduml
```

## AmazonPinpointJourneyGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonPinpointJourneyGroup
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')

' renders the element
AmazonPinpointJourneyGroup('AmazonPinpointJourneyGroup', 'Amazon Pinpoint Journey Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonPinpointJourneyGroup
include('aws-20210730/Resource/BusinessApplications/AmazonPinpointJourney')

' renders the element
AmazonPinpointJourneyGroup('AmazonPinpointJourneyGroup', 'Amazon Pinpoint Journey Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
